﻿#region License Information
/* HeuristicLab
 * Copyright (C) 2002-2013 Heuristic and Evolutionary Algorithms Laboratory (HEAL)
 *
 * This file is part of HeuristicLab.
 *
 * HeuristicLab is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * HeuristicLab is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with HeuristicLab. If not, see <http://www.gnu.org/licenses/>.
 */
#endregion

using System;
using System.Collections.Generic;

namespace HeuristicLab.Problems.Instances.QAPGenerator {
  public class QAPInstanceGeneratorProvider : ProblemInstanceProvider<QAPData> {

    public override string Name {
      get { return "QAP Instance Generators"; }
    }

    public override string Description {
      get { return "Generates QAP instances according to given parameters."; }
    }

    public override Uri WebLink {
      get { return new Uri("http://dev.heuristiclab.com"); }
    }

    public override string ReferencePublication {
      get { return null; }
    }

    public override bool CanImportData {
      get { return false; }
    }

    public override bool CanExportData {
      get { return false; }
    }

    public override IEnumerable<IDataDescriptor> GetDataDescriptors() {
      return new QAPInstanceGeneratorDescriptor[] { new TaiaQAPInstanceGeneratorDescriptor(), new TaibQAPInstanceGeneratorDescriptor() };
    }

    public override QAPData LoadData(IDataDescriptor descriptor) {
      var parameters = (descriptor as QAPInstanceGeneratorDescriptor);
      if (parameters == null) throw new ArgumentException("descriptor is not of type QAPInstanceGeneratorDescriptor", "descriptor");
      return parameters.GetInstance();
    }
  }
}
